@@ -1,10 +1,6 @@
 //! Simple example demonstrating the use of set/map/list values in both
 //! bindings and results.
-extern crate cassandra_cpp;
-extern crate futures;
-
 use cassandra_cpp::*;
-use futures::Future;
 use std::collections::hash_map::HashMap;
 
 fn do_work(session: &Session) -> Result<()> {
@@ -19,12 +15,12 @@ fn do_work(session: &Session) -> Result<()> {
 
     insert_data.bind(0, "Paul")?;
     insert_data.bind_null(1)?;
-    let mut addresses = List::new(0);
+    let mut addresses = List::new();
     addresses.append_string("george@example.com")?;
     addresses.append_string("paul@example.com")?;
     insert_data.bind(2, addresses)?;
     insert_data.bind(3, "George")?;
-    let mut phones = List::new(0);
+    let mut phones = List::new();
     phones.append_string("123-456")?;
     phones.append_string("789-012")?;
     insert_data.bind(4, phones)?; // TODO: bind should really accept Vec<T>, and map should accept HashMap<T, U>. Requires generic CassCollection::append.
@@ -42,18 +38,20 @@ fn do_work(session: &Session) -> Result<()> {
             let maybe_iter: Result<MapIterator> = row.get_by_name("addresses");
             match maybe_iter {
                 Err(_) => HashMap::new(),
-                Ok(addresses_iter) => {
-                    addresses_iter
-                        .map(|(k, v)| Ok((k.get_string()?, v.get_string()?)))
-                        .collect::<Result<_>>()?
-                }
+                Ok(addresses_iter) => addresses_iter
+                    .map(|(k, v)| Ok((k.get_string()?, v.get_string()?)))
+                    .collect::<Result<_>>()?,
             }
         };
         let emails_iter: SetIterator = row.get_by_name("email")?;
-        let emails: Vec<String> = emails_iter.map(|v| Ok(v.get_string()?)).collect::<Result<_>>()?;
+        let emails: Vec<String> = emails_iter
+            .map(|v| Ok(v.get_string()?))
+            .collect::<Result<_>>()?;
         let last_name: String = row.get_by_name("last_name")?;
         let phone_numbers_iter: SetIterator = row.get_by_name("phone_numbers")?;
-        let phone_numbers: Vec<String> = phone_numbers_iter.map(|v| Ok(v.get_string()?)).collect::<Result<_>>()?;
+        let phone_numbers: Vec<String> = phone_numbers_iter
+            .map(|v| Ok(v.get_string()?))
+            .collect::<Result<_>>()?;
         let title: i32 = row.get_by_name("title")?;
         println!(
             " == {} {:?} {:?} {} {:?} {}",
