@@ -1,11 +1,5 @@
-extern crate cassandra_cpp;
-extern crate futures;
-
 use cassandra_cpp::*;
 
-use futures::Future;
-
-
 fn main() {
     let query = stmt!("SELECT keyspace_name FROM system_schema.keyspaces;");
     let col_name = "keyspace_name";
