@@ -8,6 +8,8 @@ use crate::cassandra::util::Protected;
 
 use crate::cassandra_sys::cass_cluster_free;
 use crate::cassandra_sys::cass_cluster_new;
+use crate::cassandra_sys::cass_cluster_set_cloud_secure_connection_bundle_n;
+use crate::cassandra_sys::cass_cluster_set_cloud_secure_connection_bundle_no_ssl_lib_init_n;
 use crate::cassandra_sys::cass_cluster_set_connect_timeout;
 use crate::cassandra_sys::cass_cluster_set_connection_heartbeat_interval;
 use crate::cassandra_sys::cass_cluster_set_connection_idle_timeout;
@@ -157,6 +159,27 @@ impl Cluster {
         }
     }
 
+    /// Sets the secure connection bundle path for processing DBaaS credentials.
+    pub fn set_cloud_secure_connection_bundle(&mut self, path: &str) -> Result<&mut Self> {
+        unsafe {
+            let path_ptr = path.as_ptr() as *const c_char;
+            let err = cass_cluster_set_cloud_secure_connection_bundle_n(self.0, path_ptr, path.len());
+            err.to_result(self)
+        }
+    }
+
+    /// Sets the secure connection bundle path for processing DBaaS credentials, but it
+    /// does not initialize the underlying SSL library implementation. The SSL library still
+    /// needs to be initialized, but it's up to the client application to handle
+    /// initialization.
+    pub fn set_cloud_secure_connection_bundle_no_ssl_lib_init(&mut self, path: &str) -> Result<&mut Self> {
+        unsafe {
+            let path_ptr = path.as_ptr() as *const c_char;
+            let err = cass_cluster_set_cloud_secure_connection_bundle_no_ssl_lib_init_n(self.0, path_ptr, path.len());
+            err.to_result(self)
+        }
+    }
+
     /// Performs a blocking call to connect to Cassandra cluster
     pub fn connect(&mut self) -> Result<Session> {
         unsafe {
