@@ -1,10 +1,10 @@
-use cassandra::util::Protected;
-use cassandra_sys::CassRetryPolicy as _RetryPolicy;
-use cassandra_sys::cass_retry_policy_default_new;
-use cassandra_sys::cass_retry_policy_downgrading_consistency_new;
-use cassandra_sys::cass_retry_policy_fallthrough_new;
-use cassandra_sys::cass_retry_policy_free;
-use cassandra_sys::cass_retry_policy_logging_new;
+use crate::cassandra::util::Protected;
+use crate::cassandra_sys::cass_retry_policy_default_new;
+use crate::cassandra_sys::cass_retry_policy_downgrading_consistency_new;
+use crate::cassandra_sys::cass_retry_policy_fallthrough_new;
+use crate::cassandra_sys::cass_retry_policy_free;
+use crate::cassandra_sys::cass_retry_policy_logging_new;
+use crate::cassandra_sys::CassRetryPolicy as _RetryPolicy;
 
 /// The selected retry policy
 #[derive(Debug)]
@@ -15,13 +15,22 @@ pub struct RetryPolicy(*mut _RetryPolicy);
 unsafe impl Send for RetryPolicy {}
 
 impl Protected<*mut _RetryPolicy> for RetryPolicy {
-    fn inner(&self) -> *mut _RetryPolicy { self.0 }
-    fn build(inner: *mut _RetryPolicy) -> Self { if inner.is_null() { panic!("Unexpected null pointer") }; RetryPolicy(inner) }
+    fn inner(&self) -> *mut _RetryPolicy {
+        self.0
+    }
+    fn build(inner: *mut _RetryPolicy) -> Self {
+        if inner.is_null() {
+            panic!("Unexpected null pointer")
+        };
+        RetryPolicy(inner)
+    }
 }
 
 impl RetryPolicy {
     /// The default retry policy
-    pub fn default_new() -> Self { unsafe { RetryPolicy::build(cass_retry_policy_default_new()) } }
+    pub fn default_new() -> Self {
+        unsafe { RetryPolicy::build(cass_retry_policy_default_new()) }
+    }
 
     /// An auto-CL-downgrading consistency level
     pub fn downgrading_consistency_new() -> Self {
@@ -29,7 +38,9 @@ impl RetryPolicy {
     }
 
     /// a fallthrough retry policy
-    pub fn fallthrough_new() -> Self { unsafe { RetryPolicy(cass_retry_policy_fallthrough_new()) } }
+    pub fn fallthrough_new() -> Self {
+        unsafe { RetryPolicy(cass_retry_policy_fallthrough_new()) }
+    }
 
     /// The a logging retry policy
     pub fn logging_new(child_retry_policy: RetryPolicy) -> Self {
