@@ -1,4 +1,4 @@
-use crate::cassandra::collection::Set;
+use crate::cassandra::collection::{List, Map, Set};
 use crate::cassandra::data_type::ConstDataType;
 use crate::cassandra::data_type::DataType;
 use crate::cassandra::error::*;
@@ -25,15 +25,15 @@ use crate::cassandra_sys::cass_tuple_set_int32;
 use crate::cassandra_sys::cass_tuple_set_int64;
 use crate::cassandra_sys::cass_tuple_set_int8;
 use crate::cassandra_sys::cass_tuple_set_null;
-use crate::cassandra_sys::cass_tuple_set_string;
+use crate::cassandra_sys::cass_tuple_set_string_n;
 use crate::cassandra_sys::cass_tuple_set_tuple;
 use crate::cassandra_sys::cass_tuple_set_uint32;
 use crate::cassandra_sys::cass_tuple_set_user_type;
 use crate::cassandra_sys::cass_tuple_set_uuid;
 use crate::cassandra_sys::CassTuple as _Tuple;
 
-use std::ffi::CString;
 use std::net::IpAddr;
+use std::os::raw::c_char;
 
 /// A tuple of values.
 #[derive(Debug)]
@@ -126,8 +126,9 @@ impl Tuple {
         S: Into<String>,
     {
         unsafe {
-            let value_cstr = CString::new(value.into())?;
-            cass_tuple_set_string(self.0, index, value_cstr.as_ptr()).to_result(self)
+            let value_str = value.into();
+            let value_ptr = value_str.as_ptr() as *const c_char;
+            cass_tuple_set_string_n(self.0, index, value_ptr, value_str.len()).to_result(self)
         }
     }
 
@@ -150,8 +151,24 @@ impl Tuple {
         unsafe { cass_tuple_set_inet(self.0, index, inet.inner()).to_result(self) }
     }
 
-    /// Sets a "list", "map" or "set" in a tuple at the specified index.
-    pub fn set_collection<S>(&mut self, index: usize, value: S) -> Result<&mut Self>
+    /// Sets a list in a tuple at the specified index.
+    pub fn set_list<S>(&mut self, index: usize, value: S) -> Result<&mut Self>
+    where
+        S: Into<List>,
+    {
+        unsafe { cass_tuple_set_collection(self.0, index, value.into().inner()).to_result(self) }
+    }
+
+    /// Sets a map in a tuple at the specified index.
+    pub fn set_map<S>(&mut self, index: usize, value: S) -> Result<&mut Self>
+    where
+        S: Into<Map>,
+    {
+        unsafe { cass_tuple_set_collection(self.0, index, value.into().inner()).to_result(self) }
+    }
+
+    /// Sets a set" in a tuple at the specified index.
+    pub fn set_set<S>(&mut self, index: usize, value: S) -> Result<&mut Self>
     where
         S: Into<Set>,
     {
