@@ -1,8 +1,8 @@
 mod help;
 
 use cassandra_cpp::*;
+use std::time::Duration;
 use std::time::SystemTime;
-use time::Duration;
 
 #[derive(Debug, PartialEq, Copy, Clone, Default)]
 struct Udt {
@@ -10,7 +10,7 @@ struct Udt {
     tm: i64,
 }
 
-#[derive(Debug, PartialEq, Copy, Clone, Default)]
+#[derive(Debug, PartialEq, Clone, Default)]
 struct Basic {
     bln: bool,
     flt: f32,
@@ -24,6 +24,7 @@ struct Basic {
     tu: Uuid,
     id: Uuid,
     ct: Udt,
+    txt: String,
 }
 
 /// Create the table for basic testing.
@@ -33,17 +34,48 @@ fn create_basic_table(session: &Session) {
     let table_statement = &stmt!(
         "CREATE TABLE IF NOT EXISTS examples.basic (key text, bln boolean, flt \
          float, dbl double, i8 tinyint, i16 smallint, i32 int, i64 bigint, \
-         ts timestamp, addr inet, tu timeuuid, id uuid, ct udt, PRIMARY KEY (key));"
+         ts timestamp, addr inet, tu timeuuid, id uuid, ct udt, txt text, PRIMARY KEY (key));"
     );
     session.execute(table_statement).wait().unwrap();
     let truncate_statement = &stmt!("TRUNCATE examples.basic;");
     session.execute(truncate_statement).wait().unwrap();
 }
 
+fn insert_into_basic_by_name(session: &Session, key: &str, basic: &Basic) -> Result<CassResult> {
+    let mut statement = stmt!(
+        "INSERT INTO examples.basic (key, bln, flt, dbl, i8, i16, i32, i64, ts, addr, tu, id, ct, txt) \
+         VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?);"
+    );
+
+    let ct_type = DataType::new_udt(2);
+    ct_type.add_sub_value_type_by_name::<&str>("dt", ValueType::DATE)?;
+    ct_type.add_sub_value_type_by_name::<&str>("tm", ValueType::TIME)?;
+    let mut ct_udt = ct_type.new_user_type();
+    ct_udt.set_uint32_by_name("dt", basic.ct.dt)?;
+    ct_udt.set_int64_by_name("tm", basic.ct.tm)?;
+
+    statement.bind_by_name("key", key)?;
+    statement.bind_by_name("bln", basic.bln)?;
+    statement.bind_by_name("flt", basic.flt)?;
+    statement.bind_by_name("dbl", basic.dbl)?;
+    statement.bind_by_name("i8", basic.i8)?;
+    statement.bind_by_name("i16", basic.i16)?;
+    statement.bind_by_name("i32", basic.i32)?;
+    statement.bind_by_name("i64", basic.i64)?;
+    statement.bind_by_name("ts", basic.ts)?;
+    statement.bind_by_name("addr", basic.addr)?;
+    statement.bind_by_name("tu", basic.tu)?;
+    statement.bind_by_name("id", basic.id)?;
+    statement.bind_by_name("ct", &ct_udt)?;
+    statement.bind_by_name("txt", basic.txt.as_str())?;
+
+    session.execute(&statement).wait()
+}
+
 fn insert_into_basic(session: &Session, key: &str, basic: &Basic) -> Result<CassResult> {
     let mut statement = stmt!(
-        "INSERT INTO examples.basic (key, bln, flt, dbl, i8, i16, i32, i64, ts, addr, tu, id, ct) \
-         VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?);"
+        "INSERT INTO examples.basic (key, bln, flt, dbl, i8, i16, i32, i64, ts, addr, tu, id, ct, txt) \
+         VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?);"
     );
 
     let ct_type = DataType::new_udt(2);
@@ -66,11 +98,13 @@ fn insert_into_basic(session: &Session, key: &str, basic: &Basic) -> Result<Cass
     statement.bind(10, basic.tu)?;
     statement.bind(11, basic.id)?;
     statement.bind(12, &ct_udt)?;
+    statement.bind(13, basic.txt.as_str())?;
 
     session.execute(&statement).wait()
 }
 
-const SELECT_QUERY: &str = "SELECT key, bln, flt, dbl, i8, i16, i32, i64, ts, addr, tu, id, ct \
+const SELECT_QUERY: &str =
+    "SELECT key, bln, flt, dbl, i8, i16, i32, i64, ts, addr, tu, id, ct, txt \
                             FROM examples.basic WHERE key = ?";
 
 fn select_from_basic(session: &Session, key: &str) -> Result<Option<Basic>> {
@@ -105,6 +139,7 @@ fn select_from_basic(session: &Session, key: &str) -> Result<Option<Basic>> {
                 tu: row.get(10)?,
                 id: row.get(11)?,
                 ct: Udt { dt: dt, tm: tm },
+                txt: row.get(13)?,
             }))
         }
     }
@@ -133,6 +168,7 @@ fn select_from_basic_prepared(
         basic.addr = row.get(9)?;
         basic.tu = row.get(10)?;
         basic.id = row.get(11)?;
+        basic.txt = row.get(13)?;
 
         let fields_iter: UserTypeIterator = row.get(12)?;
         let mut dt: u32 = 0;
@@ -209,6 +245,7 @@ fn test_basic_round_trip() {
             dt: ts as u32,
             tm: ts as i64,
         },
+        txt: "some\0unicode text 😊".to_string(),
     };
 
     insert_into_basic(&session, "test", &input).unwrap();
@@ -220,6 +257,21 @@ fn test_basic_round_trip() {
     println!("{:?}", output);
 
     assert!(input == output);
+
+    // We are forced to use a null terminated CString to workaround a bug in the
+    // cpp driver. Therefore, null char is not allowed.
+    let input = {
+        let mut input = input;
+        input.txt = "some unicode text 😊".to_string();
+        input
+    };
+
+    insert_into_basic_by_name(&session, "test_by_name", &input).unwrap();
+    let output = select_from_basic(&session, "test_by_name")
+        .unwrap()
+        .expect("no output from select");
+
+    assert!(input == output);
 }
 
 #[test]
@@ -250,6 +302,7 @@ fn test_prepared_round_trip() {
             dt: ts as u32,
             tm: ts as i64,
         },
+        txt: "some\0text".to_string(),
     };
     let mut output = Basic::default();
 
@@ -278,7 +331,7 @@ fn test_null_retrieval() {
 
     // Read the whole row.
     let query = stmt!(
-        "SELECT key, bln, flt, dbl, i8, i16, i32, i64, ts, addr, tu, id, ct \
+        "SELECT key, bln, flt, dbl, i8, i16, i32, i64, ts, addr, tu, id, ct, txt \
          FROM examples.basic WHERE key = 'vacant';"
     );
     let result = session.execute(&query).wait().expect("select");
@@ -338,6 +391,10 @@ fn test_null_retrieval() {
     let c = row.get_column(12).expect("should be present");
     c.get_user_type().expect_err("should be null");
     assert!(c.is_null());
+
+    let c = row.get_column(13).expect("should be present");
+    c.get_user_type().expect_err("should be null");
+    assert!(c.is_null());
 }
 
 #[test]
@@ -348,8 +405,8 @@ fn test_null_insertion() {
 
     // Insert some explicit nulls.
     let mut s = stmt!(
-        "INSERT INTO examples.basic (key, bln, flt, dbl, i8, i16, i32, i64, ts, addr, tu, id, ct) \
-         VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?);"
+        "INSERT INTO examples.basic (key, bln, flt, dbl, i8, i16, i32, i64, ts, addr, tu, id, ct, txt) \
+         VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?);"
     );
     s.bind(0, "shrdlu").unwrap();
     s.bind(1, false).unwrap();
@@ -364,11 +421,12 @@ fn test_null_insertion() {
     s.bind_null(10).unwrap();
     s.bind_null(11).unwrap();
     s.bind_null(12).unwrap();
+    s.bind_null(13).unwrap();
     session.execute(&s).wait().unwrap();
 
     // Read them back.
     let s = stmt!(
-        "SELECT key, bln, flt, dbl, i8, i16, i32, i64, ts, addr, tu, id, ct \
+        "SELECT key, bln, flt, dbl, i8, i16, i32, i64, ts, addr, tu, id, ct, txt \
          FROM examples.basic WHERE key = 'shrdlu';"
     );
     let result = session.execute(&s).wait().expect("select");
@@ -388,6 +446,7 @@ fn test_null_insertion() {
     assert!(row.get_column(10).unwrap().is_null());
     assert!(row.get_column(11).unwrap().is_null());
     assert!(row.get_column(12).unwrap().is_null());
+    assert!(row.get_column(13).unwrap().is_null());
 }
 
 /// Check for a needle in a haystack, and fail if not present.
@@ -500,17 +559,6 @@ fn test_error_reporting() {
         ErrorKind::InvalidUtf8(_) => (),
         ref k => panic!("Unexpected error kind {}", k),
     }
-
-    // NUL error
-    let mut query = stmt!("SELECT ? from system_schema.tables;");
-    let err = query
-        .bind(0, "safe\0nasty!")
-        .expect_err("Should have failed!");
-    println!("Got error {} kind {:?}", err, err.kind());
-    match *err.kind() {
-        ErrorKind::StringContainsNul(_) => (),
-        ref k => panic!("Unexpected error kind {}", k),
-    }
 }
 
 #[test]
@@ -526,7 +574,7 @@ fn test_result() {
 #[test]
 fn test_statement_timeout() {
     let mut query = stmt!("SELECT * FROM system_schema.tables;");
-    query.set_statement_request_timeout(Some(Duration::milliseconds(30000 as i64)));
+    query.set_statement_request_timeout(Some(Duration::from_millis(30000)));
     let session = help::create_test_session();
     let result = session.execute(&query).wait().unwrap();
 
